@@ -1,11 +1,11 @@
 #include "sqlite_blocking.h"
 
 #include <sqlite3.h>
-
-#ifdef _WIN32
-#  include <windows.h>
+#ifndef _WIN32
+#include <unistd.h>
 #else
-#  include <unistd.h>
+#include <Windows.h>
+#define usleep(x) Sleep(x/1000)
 #endif
 
 #include "qdebug.h"
@@ -28,11 +28,7 @@ int sqlite3_blocking_step( sqlite3_stmt *pStmt )
     qDebug() << debugString() + "sqlite3_blocking_step: Entering while loop";
 
   while( rc == SQLITE_BUSY ) {
-#ifdef _WIN32
-    Sleep(5);
-#else
     usleep(5000);
-#endif
     sqlite3_reset( pStmt );
     rc = sqlite3_step( pStmt );
 
@@ -56,11 +52,7 @@ int sqlite3_blocking_prepare16_v2( sqlite3 *db,           /* Database handle. */
     qDebug() << debugString() + "sqlite3_blocking_prepare16_v2: Entering while loop";
 
   while( rc == SQLITE_BUSY ) {
-#ifdef _WIN32
-    Sleep(500);
-#else
     usleep(500000);
-#endif
     rc = sqlite3_prepare16_v2( db, zSql, nSql, ppStmt, pzTail );
 
     if ( rc != SQLITE_BUSY ) {
@@ -70,4 +62,3 @@ int sqlite3_blocking_prepare16_v2( sqlite3 *db,           /* Database handle. */
 
   return rc;
 }
-
