@@ -22,12 +22,11 @@
 #include "agenttype.h"
 #include "agentmanager.h"
 #include "../../libs/xdgbasedirs_p.h"
-#include "processcontrol.h"
+#include "akdebug.h"
 
 AgentInstance::AgentInstance(AgentManager * manager) :
     QObject( manager ),
     mManager( manager ),
-    mController( 0 ),
     mAgentControlInterface( 0 ),
     mAgentStatusInterface( 0 ),
     mSearchInterface( 0 ),
@@ -39,35 +38,14 @@ AgentInstance::AgentInstance(AgentManager * manager) :
 {
 }
 
-bool AgentInstance::start( const AgentType &agentInfo )
-{
-  Q_ASSERT( !mIdentifier.isEmpty() );
-  if ( mIdentifier.isEmpty() )
-    return false;
-  mType = agentInfo.identifier;
-  const QString executable = Akonadi::XdgBaseDirs::findExecutableFile( agentInfo.exec );
-  if ( executable.isEmpty() ) {
-    mManager->tracer()->error( QLatin1String( "AgentInstanceInfo::start" ),
-                               QString::fromLatin1( "Unable to find agent executable '%1'" ).arg( agentInfo.exec ) );
-    return false;
-  }
-  mController = new Akonadi::ProcessControl( this );
-  QStringList arguments;
-  arguments << "--identifier" << mIdentifier;
-  mController->start( executable, arguments );
-  return true;
-}
-
 void AgentInstance::quit()
 {
-  mController->setCrashPolicy( Akonadi::ProcessControl::StopOnCrash );
   if ( mAgentControlInterface && mAgentControlInterface->isValid() )
     mAgentControlInterface->quit();
 }
 
 void AgentInstance::cleanup()
 {
-  mController->setCrashPolicy( Akonadi::ProcessControl::StopOnCrash );
   if ( mAgentControlInterface && mAgentControlInterface->isValid() )
     mAgentControlInterface->cleanup();
 }
@@ -76,51 +54,24 @@ bool AgentInstance::obtainAgentInterface()
 {
   delete mAgentControlInterface;
   delete mAgentStatusInterface;
-  mAgentControlInterface = 0;
-  mAgentStatusInterface = 0;
 
-  org::freedesktop::Akonadi::Agent::Control *agentControlIface =
-    new org::freedesktop::Akonadi::Agent::Control( "org.freedesktop.Akonadi.Agent." + mIdentifier,
-                                                   "/", QDBusConnection::sessionBus(), this );
-  if ( !agentControlIface || !agentControlIface->isValid() ) {
-    mManager->tracer()->error( QLatin1String( "AgentInstance::obtainAgentInterface" ),
-      QString( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
-          .arg( mIdentifier, agentControlIface ? agentControlIface->lastError().message() : "" ) );
-
-    if ( agentControlIface )
-      delete agentControlIface;
+  mAgentControlInterface =
+    findInterface<org::freedesktop::Akonadi::Agent::Control>( "org.freedesktop.Akonadi.Agent", "/" );
+  mAgentStatusInterface =
+    findInterface<org::freedesktop::Akonadi::Agent::Status>( "org.freedesktop.Akonadi.Agent", "/" );
 
+  if ( !mAgentControlInterface || !mAgentStatusInterface )
     return false;
-  }
-  mAgentControlInterface = agentControlIface;
 
-  org::freedesktop::Akonadi::Agent::Status *agentStatusIface =
-    new org::freedesktop::Akonadi::Agent::Status( "org.freedesktop.Akonadi.Agent." + mIdentifier,
-                                                  "/", QDBusConnection::sessionBus(), this );
-  if ( !agentStatusIface || !agentStatusIface->isValid() ) {
-    mManager->tracer()->error( QLatin1String( "AgentInstance::obtainAgentInterface" ),
-      QString( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
-          .arg( mIdentifier, agentStatusIface ? agentStatusIface->lastError().message() : "" ) );
+  mSearchInterface =
+    findInterface<org::freedesktop::Akonadi::Agent::Search>( "org.freedesktop.Akonadi.Agent", "/Search" );
 
-    if ( agentStatusIface )
-      delete agentStatusIface;
-
-    return false;
-  }
-  mAgentStatusInterface = agentStatusIface;
-
-  mSearchInterface = new org::freedesktop::Akonadi::Agent::Search( "org.freedesktop.Akonadi.Agent." + mIdentifier,
-                                                                   "/Search", QDBusConnection::sessionBus(), this );
-  if ( !mSearchInterface || !mSearchInterface->isValid() ) {
-    delete mSearchInterface;
-    mSearchInterface = 0;
-  }
-
-  connect( agentStatusIface, SIGNAL(status(int,QString)), SLOT(statusChanged(int,QString)) );
-  connect( agentStatusIface, SIGNAL(percent(int)), SLOT(percentChanged(int)) );
-  connect( agentStatusIface, SIGNAL(warning(QString)), SLOT(warning(QString)) );
-  connect( agentStatusIface, SIGNAL(error(QString)), SLOT(error(QString)) );
-  connect( agentStatusIface, SIGNAL(onlineChanged(bool)), SLOT(onlineChanged(bool)) );
+  connect( mAgentStatusInterface, SIGNAL(status(int,QString)), SLOT(statusChanged(int,QString)) );
+  connect( mAgentStatusInterface, SIGNAL(advancedStatus(QVariantMap)), SLOT(advancedStatusChanged(QVariantMap)) );
+  connect( mAgentStatusInterface, SIGNAL(percent(int)), SLOT(percentChanged(int)) );
+  connect( mAgentStatusInterface, SIGNAL(warning(QString)), SLOT(warning(QString)) );
+  connect( mAgentStatusInterface, SIGNAL(error(QString)), SLOT(error(QString)) );
+  connect( mAgentStatusInterface, SIGNAL(onlineChanged(bool)), SLOT(onlineChanged(bool)) );
 
   refreshAgentStatus();
   return true;
@@ -129,66 +80,23 @@ bool AgentInstance::obtainAgentInterface()
 bool AgentInstance::obtainResourceInterface()
 {
   delete mResourceInterface;
-  mResourceInterface = 0;
-
-  org::freedesktop::Akonadi::Resource *resInterface =
-    new org::freedesktop::Akonadi::Resource( "org.freedesktop.Akonadi.Resource." + mIdentifier,
-                                              "/", QDBusConnection::sessionBus(), this );
-
-  if ( !resInterface || !resInterface->isValid() ) {
-    mManager->tracer()->error( QLatin1String( "AgentInstance::obtainResourceInterface" ),
-      QString( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
-          .arg( mIdentifier, resInterface ? resInterface->lastError().message() : "" ) );
-
-    if ( resInterface )
-      delete resInterface;
+  mResourceInterface =
+    findInterface<org::freedesktop::Akonadi::Resource>( "org.freedesktop.Akonadi.Resource", "/" );
 
+  if ( !mResourceInterface )
     return false;
-  }
-
-  connect( resInterface, SIGNAL(nameChanged(QString)), SLOT(resourceNameChanged(QString)) );
-  mResourceInterface = resInterface;
 
+  connect( mResourceInterface, SIGNAL(nameChanged(QString)), SLOT(resourceNameChanged(QString)) );
   refreshResourceStatus();
   return true;
 }
 
 bool AgentInstance::obtainPreprocessorInterface()
 {
-  // Cleanup if it was already present
-  if( mPreprocessorInterface )
-  {
-    delete mPreprocessorInterface;
-    mPreprocessorInterface = 0;
-  }
-
-  org::freedesktop::Akonadi::Preprocessor * preProcessorInterface =
-    new org::freedesktop::Akonadi::Preprocessor(
-        "org.freedesktop.Akonadi.Preprocessor." + mIdentifier,
-        "/",
-        QDBusConnection::sessionBus(),
-        this
-      );
-
-  if ( !preProcessorInterface || !preProcessorInterface->isValid() )
-  {
-    // The agent likely doesn't export the preprocessor interface
-    // or there is some D-Bus quirk that prevents us from accessing it.
-    mManager->tracer()->error(
-        QLatin1String( "AgentInstance::obtainPreprocessorInterface" ),
-        QString( "Cannot connect to agent instance with identifier '%1', error message: '%2'" )
-          .arg( mIdentifier, preProcessorInterface ? preProcessorInterface->lastError().message() : "" )
-      );
-
-    if ( preProcessorInterface )
-      delete preProcessorInterface;
-
-    return false;
-  }
-
-  mPreprocessorInterface = preProcessorInterface;
-
-  return true;
+  delete mPreprocessorInterface;
+  mPreprocessorInterface =
+    findInterface<org::freedesktop::Akonadi::Preprocessor>( "org.freedesktop.Akonadi.Preprocessor", "/" );
+  return mPreprocessorInterface;
 }
 
 void AgentInstance::statusChanged(int status, const QString & statusMsg)
@@ -200,6 +108,11 @@ void AgentInstance::statusChanged(int status, const QString & statusMsg)
   emit mManager->agentInstanceStatusChanged( mIdentifier, mStatus, mStatusMessage );
 }
 
+void AgentInstance::advancedStatusChanged( const QVariantMap &status )
+{
+  emit mManager->agentInstanceAdvancedStatusChanged( mIdentifier, status );
+}
+
 void AgentInstance::statusStateChanged(int status)
 {
   statusChanged( status, mStatusMessage );
@@ -282,12 +195,20 @@ void AgentInstance::errorHandler(const QDBusError & error)
   // TODO try again after some time, esp. on timeout errors
 }
 
-void AgentInstance::restartWhenIdle()
+template <typename T>
+T* AgentInstance::findInterface(const char* service, const char* path)
 {
-  if ( mStatus == 0 ) {
-    mController->restartOnceWhenFinished();
-    quit();
+  T * iface = new T( QString::fromLatin1( "%1.%2" ).arg( service ).arg( mIdentifier ),
+                     QLatin1String( path ), QDBusConnection::sessionBus(), this );
+
+  if ( !iface || !iface->isValid() ) {
+    akError() << Q_FUNC_INFO << "Cannot connect to agent instance with identifier" << mIdentifier
+              << ", error message:" << (iface ? iface->lastError().message() : "");
+    delete iface;
+    return 0;
   }
+  return iface;
 }
 
+
 #include "agentinstance.moc"
