@@ -28,7 +28,7 @@ ControlManager::ControlManager( QObject *parent )
   : QObject( parent )
 {
   new ControlManagerAdaptor( this );
-  QDBusConnection::sessionBus().registerObject( QLatin1String( "/ControlManager" ), this );
+  QDBusConnection::sessionBus().registerObject( "/ControlManager", this );
 }
 
 ControlManager::~ControlManager()
@@ -37,5 +37,7 @@ ControlManager::~ControlManager()
 
 void ControlManager::shutdown()
 {
-  QTimer::singleShot( 0, QCoreApplication::instance(), SLOT(quit()) );
+  QTimer::singleShot( 0, QCoreApplication::instance(), SLOT( quit() ) );
 }
+
+#include "controlmanager.moc"
