@@ -32,6 +32,12 @@
 
 #include <cstdlib>
 
+#ifdef QT_STATICPLUGIN
+#include <QtPlugin>
+
+Q_IMPORT_PLUGIN(qsqlite3)
+#endif
+
 #ifndef _WIN32_WCE
 namespace po = boost::program_options;
 #endif
@@ -47,10 +53,11 @@ void shutdownHandler( int )
 
 int main( int argc, char ** argv )
 {
+    Q_INIT_RESOURCE( akonadidb );
     AkApplication app( argc, argv );
     app.setDescription( QLatin1String( "Akonadi Server\nDo not run manually, use 'akonadictl' instead to start/stop Akonadi." ) );
 
-#ifndef NDEBUG
+#if !defined(NDEBUG) && !defined(_WIN32_WCE)
     po::options_description debugOptions( "Debug options (use with care)" );
     debugOptions.add_options()
         ( "start-without-control", "Allow to start the Akonadi server even without the Akonadi control process being available" );
@@ -63,14 +70,14 @@ int main( int argc, char ** argv )
     #undef interface
 
 #ifndef _WIN32_WCE
-    if ( !app.commandLineArguments().count( "start-without-control" ) &&
+   if ( !app.commandLineArguments().count( "start-without-control" ) &&
 #else
-    if (
+   if (
 #endif
-         !QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE_LOCK) ) ) {
-      akError() << "Akonadi control process not found - aborting.";
-      akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
-    }
+        !QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE_LOCK) ) ) {
+     akError() << "Akonadi control process not found - aborting.";
+     akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
+   }
 
     Akonadi::AkonadiServer::instance(); // trigger singleton creation
     AkonadiCrash::setShutdownMethod( shutdownHandler );
@@ -82,5 +89,6 @@ int main( int argc, char ** argv )
 
     Akonadi::AkonadiServer::instance()->quit();
 
+    Q_CLEANUP_RESOURCE( akonadidb );
     return result;
 }
