@@ -26,6 +26,7 @@
 #include "handler/scope.h"
 #include "handler.h"
 #include "storage/queryhelper.h"
+#include "collectionqueryhelper.h"
 
 using namespace Akonadi;
 
@@ -34,10 +35,9 @@ void ItemQueryHelper::itemSetToQuery(const ImapSet& set, QueryBuilder& qb, const
   QueryHelper::setToQuery( set, PimItem::idFullColumnName(), qb );
   if ( collection.isValid() ) {
     if ( collection.resource().isVirtual() ) {
-      qb.addTable( CollectionPimItemRelation::tableName() );
+      qb.addJoin( QueryBuilder::InnerJoin, CollectionPimItemRelation::tableName(),
+                  CollectionPimItemRelation::rightFullColumnName(), PimItem::idFullColumnName() );
       qb.addValueCondition( CollectionPimItemRelation::leftFullColumnName(), Query::Equals, collection.id() );
-      qb.addColumnCondition( CollectionPimItemRelation::rightFullColumnName(), Query::Equals,
-                             PimItem::idFullColumnName() );
     } else {
       qb.addValueCondition( PimItem::collectionIdColumn(), Query::Equals, collection.id() );
     }
@@ -60,11 +60,10 @@ void ItemQueryHelper::remoteIdToQuery(const QStringList& rids, AkonadiConnection
     qb.addValueCondition( PimItem::remoteIdFullColumnName(), Query::In, rids );
 
   if ( connection->resourceContext().isValid() ) {
-    qb.addTable( Collection::tableName() );
-    qb.addColumnCondition( PimItem::collectionIdFullColumnName(), Query::Equals, Collection::idFullColumnName() );
+    qb.addJoin( QueryBuilder::InnerJoin, Collection::tableName(),
+                PimItem::collectionIdFullColumnName(), Collection::idFullColumnName() );
     qb.addValueCondition( Collection::resourceIdFullColumnName(), Query::Equals, connection->resourceContext().id() );
   } else if ( connection->selectedCollectionId() > 0 ) {
-    qb.addTable( Collection::tableName() );
     qb.addValueCondition( PimItem::collectionIdFullColumnName(), Query::Equals, connection->selectedCollectionId() );
   }
 }
@@ -73,10 +72,24 @@ void ItemQueryHelper::scopeToQuery(const Scope& scope, AkonadiConnection* connec
 {
   if ( scope.scope() == Scope::None || scope.scope() == Scope::Uid ) {
     itemSetToQuery( scope.uidSet(), scope.scope() == Scope::Uid, connection, qb );
-  } else if ( scope.scope() == Scope::Rid ) {
-    if ( connection->selectedCollectionId() <= 0 && !connection->resourceContext().isValid() )
+    return;
+  }
+
+  if ( connection->selectedCollectionId() <= 0 && !connection->resourceContext().isValid() )
       throw HandlerException( "Operations based on remote identifiers require a resource or collection context" );
+
+  if ( scope.scope() == Scope::Rid ) {
     ItemQueryHelper::remoteIdToQuery( scope.ridSet(), connection, qb );
-  } else
-    throw HandlerException( "WTF?" );
+    return;
+  } else if ( scope.scope() == Scope::HierarchicalRid ) {
+    QStringList ridChain = scope.ridChain();
+    const QString itemRid = ridChain.takeFirst();
+    const Collection parentCol = CollectionQueryHelper::resolveHierarchicalRID( ridChain, connection->resourceContext().id() );
+    const Collection::Id oldSelection = connection->selectedCollectionId();
+    remoteIdToQuery( QStringList() << itemRid, connection, qb );
+    connection->setSelectedCollection( oldSelection );
+    return;
+  }
+
+  throw HandlerException( "Dude, WTF?!?" );
 }
