@@ -21,8 +21,6 @@
 #include "querybuildertest.moc"
 
 #define QUERYBUILDER_UNITTEST
-// need to disable the DLL stuff
-#define AKONADIPRIVATE_EXPORT
 
 #include "storage/query.cpp"
 #include "storage/querybuilder.cpp"
@@ -70,6 +68,11 @@ void QueryBuilderTest::testQueryBuilder_data()
   mBuilders << qb;
   QTest::newRow( "hierarchical where" ) << mBuilders.count() << QString( "SELECT col1, col2 FROM table WHERE ( col1 = :0 OR col1 <= col2 OR ( col1 > col2 AND col1 <> NULL ) )" ) << bindVals;
 
+  qb = QueryBuilder( "table" );
+  qb.addAggregation( "col1", "count" );
+  mBuilders << qb;
+  QTest::newRow( "single aggregation" ) << mBuilders.count() << QString( "SELECT count(col1) FROM table" ) << QList<QVariant>();
+
   qb = QueryBuilder( "table" );
   qb.addColumn( "col1" );
   qb.addSortColumn( "col1" );
@@ -97,6 +100,13 @@ void QueryBuilderTest::testQueryBuilder_data()
   mBuilders << qb;
   QTest::newRow( "SELECT with LIMIT" ) << mBuilders.count() << QString( "SELECT col1 FROM table LIMIT 1" ) << QList<QVariant>();
 
+  qb = QueryBuilder( "table", QueryBuilder::Select );
+  qb.setDatabaseType( QueryBuilder::Virtuoso );
+  qb.addColumn( "col1" );
+  qb.setLimit( 1 );
+  mBuilders << qb;
+  QTest::newRow( "SELECT with TOP" ) << mBuilders.count() << QString( "SELECT TOP 1 col1 FROM table" ) << QList<QVariant>();
+
   qb = QueryBuilder( "table", QueryBuilder::Update );
   qb.setColumnValue( "col1", QString( "bla" ) );
   bindVals.clear();
